# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_tools_item_name_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemNameItem,
)

TemplatesCreateAgentsResponseAgentsItemToolsItemName = typing.Union[
    str, typing.Optional[str], typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemNameItem]]
]



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .agents_search_response_agents_item_sources_item_id import AgentsSearchResponseAgentsItemSourcesItemId
from .agents_search_response_agents_item_sources_item_description import (
    AgentsSearchResponseAgentsItemSourcesItemDescription,
)
from .agents_search_response_agents_item_sources_item_embedding_config import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig,
)
from .agents_search_response_agents_item_sources_item_organization_id import (
    AgentsSearchResponseAgentsItemSourcesItemOrganizationId,
)
from .agents_search_response_agents_item_sources_item_metadata import AgentsSearchResponseAgentsItemSourcesItemMetadata
from .agents_search_response_agents_item_sources_item_created_by_id import (
    AgentsSearchResponseAgentsItemSourcesItemCreatedById,
)
from .agents_search_response_agents_item_sources_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById,
)
from .agents_search_response_agents_item_sources_item_created_at import (
    AgentsSearchResponseAgentsItemSourcesItemCreatedAt,
)
from .agents_search_response_agents_item_sources_item_updated_at import (
    AgentsSearchResponseAgentsItemSourcesItemUpdatedAt,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentsSearchResponseAgentsItemSourcesItem(UncheckedBaseModel):
    id: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemId] = None
    name: str
    description: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemDescription] = None
    embedding_config: AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig
    organization_id: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemOrganizationId] = None
    metadata: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemMetadata] = None
    created_by_id: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemCreatedById] = None
    last_updated_by_id: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById] = None
    created_at: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemCreatedAt] = None
    updated_at: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemUpdatedAt] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_created_by_id import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_created_at import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_updated_at import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_id import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemId,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_description import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_organization_id import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItem(UncheckedBaseModel):
    created_by_id: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById
    ] = None
    last_updated_by_id: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById
    ] = None
    created_at: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt] = None
    updated_at: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt] = None
    id: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemId] = None
    key: str
    value: str
    description: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescription] = (
        None
    )
    organization_id: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId
    ] = None
    agent_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsManagerType = typing.Union[
    typing.Literal["round_robin", "supervisor", "dynamic", "swarm"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .templates_create_agents_response_agents_item_tools_item_tool_type import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemToolType,
)
from .templates_create_agents_response_agents_item_tools_item_description import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemDescription,
)
from .templates_create_agents_response_agents_item_tools_item_source_type import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemSourceType,
)
from .templates_create_agents_response_agents_item_tools_item_organization_id import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationId,
)
from .templates_create_agents_response_agents_item_tools_item_name import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemName,
)
from .templates_create_agents_response_agents_item_tools_item_source_code import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemSourceCode,
)
from .templates_create_agents_response_agents_item_tools_item_json_schema import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemJsonSchema,
)
from .templates_create_agents_response_agents_item_tools_item_args_json_schema import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemArgsJsonSchema,
)
from .templates_create_agents_response_agents_item_tools_item_created_by_id import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemCreatedById,
)
from .templates_create_agents_response_agents_item_tools_item_last_updated_by_id import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedById,
)
import typing_extensions
from .templates_create_agents_response_agents_item_tools_item_metadata import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemMetadata,
)
from ...core.serialization import FieldMetadata
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsResponseAgentsItemToolsItem(UncheckedBaseModel):
    id: typing.Optional[str] = None
    tool_type: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemToolType] = None
    description: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemDescription] = None
    source_type: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemSourceType] = None
    organization_id: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationId] = None
    name: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemName] = None
    tags: typing.Optional[typing.List[str]] = None
    source_code: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemSourceCode] = None
    json_schema: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemJsonSchema] = None
    args_json_schema: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemArgsJsonSchema] = None
    return_char_limit: typing.Optional[float] = None
    created_by_id: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemCreatedById] = None
    last_updated_by_id: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemLastUpdatedById] = None
    metadata: typing_extensions.Annotated[
        typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemMetadata], FieldMetadata(alias="metadata_")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_multi_agent_group_agent_ids import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIds,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItem,
)

TemplatesCreateAgentsResponseAgentsItemMultiAgentGroup = typing.Union[
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIds,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItem]],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_tool_rules_item_item_child_output_mapping_default_child_item import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
)

TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild = typing.Union[
    str,
    typing.Optional[str],
    typing.List[
        typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem]
    ],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_tool_rules_item_item import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItem,
)

TemplatesCreateAgentsResponseAgentsItemToolRulesItem = typing.Union[
    typing.List[TemplatesCreateAgentsResponseAgentsItemToolRulesItemItem], typing.Optional[str]
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tool_rules_item_item_children import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildren,
)
from .agents_search_response_agents_item_tool_rules_item_item_one import (
    AgentsSearchResponseAgentsItemToolRulesItemItemOne,
)
from .agents_search_response_agents_item_tool_rules_item_item_two import (
    AgentsSearchResponseAgentsItemToolRulesItemItemTwo,
)
from .agents_search_response_agents_item_tool_rules_item_item_child_output_mapping import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMapping,
)
from .agents_search_response_agents_item_tool_rules_item_item_four import (
    AgentsSearchResponseAgentsItemToolRulesItemItemFour,
)
from .agents_search_response_agents_item_tool_rules_item_item_max_count_limit import (
    AgentsSearchResponseAgentsItemToolRulesItemItemMaxCountLimit,
)

AgentsSearchResponseAgentsItemToolRulesItemItem = typing.Union[
    AgentsSearchResponseAgentsItemToolRulesItemItemChildren,
    AgentsSearchResponseAgentsItemToolRulesItemItemOne,
    AgentsSearchResponseAgentsItemToolRulesItemItemTwo,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemItemFour,
    AgentsSearchResponseAgentsItemToolRulesItemItemMaxCountLimit,
]



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .agents_search_response_agents_item_memory_blocks_item_limit import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLimit,
)
from .agents_search_response_agents_item_memory_blocks_item_name import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemName,
)
from .agents_search_response_agents_item_memory_blocks_item_is_template import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate,
)
from .agents_search_response_agents_item_memory_blocks_item_label import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLabel,
)
from .agents_search_response_agents_item_memory_blocks_item_description import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemDescription,
)
from .agents_search_response_agents_item_memory_blocks_item_metadata import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata,
)
from .agents_search_response_agents_item_memory_blocks_item_id import AgentsSearchResponseAgentsItemMemoryBlocksItemId
from .agents_search_response_agents_item_memory_blocks_item_organization_id import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId,
)
from .agents_search_response_agents_item_memory_blocks_item_created_by_id import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById,
)
from .agents_search_response_agents_item_memory_blocks_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentsSearchResponseAgentsItemMemoryBlocksItem(UncheckedBaseModel):
    value: str
    limit: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemLimit] = None
    name: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemName] = None
    is_template: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate] = None
    label: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemLabel] = None
    description: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemDescription] = None
    metadata: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata] = None
    id: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemId] = None
    organization_id: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId] = None
    created_by_id: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById] = None
    last_updated_by_id: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_manager_type import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerType,
)
import typing
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_manager_agent_id import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentId,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_termination_token import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationToken,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_max_turns import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurns,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIds(UncheckedBaseModel):
    id: str
    manager_type: TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerType
    agent_ids: typing.List[str]
    description: str
    manager_agent_id: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentId
    ] = None
    termination_token: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationToken
    ] = None
    max_turns: typing.Optional[TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurns] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .components_schemas_text_content import ComponentsSchemasTextContent

UpdateAssistantMessageContent = typing.Union[typing.List[ComponentsSchemasTextContent], str]



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_multi_agent_group_item_agent_ids import (
    AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIds,
)

AgentsSearchResponseAgentsItemMultiAgentGroupItem = typing.Union[
    AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIds, typing.Optional[str]
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_message_ids_item import (
    TemplatesCreateAgentsResponseAgentsItemMessageIdsItem,
)

TemplatesCreateAgentsResponseAgentsItemMessageIds = typing.Union[
    typing.List[str],
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemMessageIdsItem]],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_request_search_item_zero import AgentsSearchRequestSearchItemZero
from .agents_search_request_search_item_one import AgentsSearchRequestSearchItemOne
from .agents_search_request_search_item_field import AgentsSearchRequestSearchItemField

AgentsSearchRequestSearchItem = typing.Union[
    AgentsSearchRequestSearchItemZero, AgentsSearchRequestSearchItemOne, AgentsSearchRequestSearchItemField
]



# This file was auto-generated by Fern from our API Definition.

import typing
from ...types.completion_create_params_non_streaming import CompletionCreateParamsNonStreaming
from ...types.completion_create_params_streaming import CompletionCreateParamsStreaming

CreateVoiceChatCompletionsRequest = typing.Union[CompletionCreateParamsNonStreaming, CompletionCreateParamsStreaming]



# This file was auto-generated by Fern from our API Definition.

from .add_mcp_server_request import AddMcpServerRequest
from .add_mcp_server_response_item import AddMcpServerResponseItem
from .delete_mcp_server_response_item import DeleteMcpServerResponseItem
from .list_mcp_servers_response_value import ListMcpServersResponseValue

__all__ = [
    "AddMcpServerRequest",
    "AddMcpServerResponseItem",
    "DeleteMcpServerResponseItem",
    "ListMcpServersResponseValue",
]



# This file was auto-generated by Fern from our API Definition.

import typing

ChatCompletionAudioParamVoice = typing.Union[
    typing.Literal["alloy", "ash", "ballad", "coral", "echo", "sage", "shimmer", "verse"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .chat_completion_function_call_option_param import ChatCompletionFunctionCallOptionParam

CompletionCreateParamsNonStreamingFunctionCall = typing.Union[
    typing.Literal["none"], typing.Literal["auto"], ChatCompletionFunctionCallOptionParam
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tool_rules_item import AgentsSearchResponseAgentsItemToolRulesItem

AgentsSearchResponseAgentsItemToolRules = typing.Union[
    typing.List[AgentsSearchResponseAgentsItemToolRulesItem],
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemToolRulesItem]],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .templates_create_agents_response_agents_item_tool_rules_item_child_output_mapping_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingType,
)
from .templates_create_agents_response_agents_item_tool_rules_item_child_output_mapping_default_child import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild,
)
from .templates_create_agents_response_agents_item_tool_rules_item_child_output_mapping_require_output_mapping import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMapping(UncheckedBaseModel):
    tool_name: str
    type: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingType] = None
    default_child: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild
    ] = None
    child_output_mapping: typing.Optional[typing.Optional[typing.Any]] = None
    require_output_mapping: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_multi_agent_group_item_agent_ids_termination_token_item import (
    AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem,
)

AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationToken = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem]],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from .mcp_server_type import McpServerType
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class SseServerConfig(UncheckedBaseModel):
    server_name: str = pydantic.Field()
    """
    The name of the server
    """

    type: typing.Optional[McpServerType] = None
    server_url: str = pydantic.Field()
    """
    The URL of the server (MCP SSE client will connect to this URL)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .templates_create_agents_response_agents_item_tool_rules_item_max_count_limit_type import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemMaxCountLimitType,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsResponseAgentsItemToolRulesItemMaxCountLimit(UncheckedBaseModel):
    tool_name: str
    type: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolRulesItemMaxCountLimitType] = None
    max_count_limit: float

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_multi_agent_group_agent_ids import (
    AgentsSearchResponseAgentsItemMultiAgentGroupAgentIds,
)
from .agents_search_response_agents_item_multi_agent_group_item import AgentsSearchResponseAgentsItemMultiAgentGroupItem

AgentsSearchResponseAgentsItemMultiAgentGroup = typing.Union[
    AgentsSearchResponseAgentsItemMultiAgentGroupAgentIds,
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemMultiAgentGroupItem]],
    typing.Optional[typing.Any],
]
